%global __brp_check_rpaths %{nil}
# /usr/bin/openmw-cs contains an invalid runpath

%global git_date  20241023
%global git_hash  cd2f261ff5

%global rel  1

%global git_ver  0.49.0
%global src_name  %{name}-%{git_date}-%{git_hash}.tar.xz

Name:           openmw
Version:	%{git_ver}^%{git_date}g%{git_hash}
Release:	%{rel}%{?dist}
Summary:        Unofficial open source engine re-implementation of the game Morrowind

License:        GPLv3 and MIT and zlib
URL:            https://openmw.org
Source0:	%{url}/%{src_name}
#Patch0:		physicssystem_hpp_algorithm.patch
#Patch1:		pathgrid_cpp_algorithm.patch
#Patch2:		opencs-shared-lib.patch


BuildRequires:  cmake3 git make gcc-c++ ccache wget
BuildRequires:  bullet-devel
BuildRequires:  desktop-file-utils
BuildRequires:  libblkid-devel
BuildRequires:  libmpg123-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libXt-devel
BuildRequires:  mygui-devel
BuildRequires:  openal-soft-devel
BuildRequires:  openexr-devel
BuildRequires:  qt6-qtbase-devel
BuildRequires:  SDL2-devel
BuildRequires:  tinyxml-devel
# Can't use git version of FFMPEG due to "avutil: remove deprecated FF_API_OLD_CHANNEL_LAYOUT"
# https://github.com/FFmpeg/FFmpeg/commit/65ddc74988245a01421a63c5cffa4d900c47117c
BuildRequires:  ffmpeg-devel ffmpeg-libs
#BuildRequires:  ffmpeg6_1-devel ffmpeg6_1-libs
BuildRequires:  unshield-devel unshield
BuildRequires:  libappstream-glib
BuildRequires:  OpenSceneGraph-OMW-devel OpenThreads-OMW-devel
BuildRequires:  gtest-devel
BuildRequires:  gmock-devel
BuildRequires:  tango-icon-theme
BuildRequires:  dejavu-lgc-sans-mono-fonts
BuildRequires:  lz4-devel
BuildRequires:  python3-devel
BuildRequires:  luajit-devel
BuildRequires:  sqlite-devel
BuildRequires:  yaml-cpp-devel
BuildRequires:  recastnavigation-devel
BuildRequires:  pkgconfig(zlib)
#BuildRequires:  openCOLLADA-devel
BuildRequires:  qt6-qttools-devel
BuildRequires:  qt6-qtsvg-devel

Requires:       dejavu-lgc-sans-mono-fonts
Requires:       tango-icon-theme

# Version in openmw is modified.
Provides:       bundled(ocis)


%description
OpenMW is a new engine for 2002's Game of the Year,
The Elder Scrolls 3: Morrowind.

It aims to be a fully playable (and improved!), open source implementation of
the game's engine and functionality. You will still need the original game data
to play OpenMW.

##%%package cs
##Summary:  Construction Set for %{name}
##Requires:  %{name}%{?_isa} = %{version}-%{release}

##%%description cs
##Construction Set for %{name}


%prep
%autosetup -p1 -n %{name}

# Remove bundled tinyxml files
rm -f extern/oics/tiny*.*

# Unbundle dejavu-lgc-sans-mono-fonts
rm -f files/mygui/DejaVuLGCSansMono.ttf

# Unbundle tango icons
#rm -rf files/wizard/icons/
#rm -rf files/launcher/icons/

%build
%cmake -DDATADIR:PATH=%{_datadir}/%{name} \
       -DLIBDIR=%{_libdir} \
       -DBINDIR=%{_bindir} \
       -DDATAROOTDIR:PATH=%{_datadir} \
       -DGLOBAL_DATA_PATH:PATH=%{_datadir} \
       -DICONDIR=%{_datadir}/pixmaps \
       -DMORROWIND_RESOURCE_FILES=%{_datadir}/%{name}/resources \
       -DOPENMW_RESOURCE_FILES=%{_datadir}/%{name}/resources \
       -DMORROWIND_DATA_FILES=%{_datadir}/%{name}/data \
       -DUSE_SYSTEM_TINYXML=TRUE \
       -DBUILD_OPENCS=ON \
       -DBUILD_LAUNCHER=ON \
       -DBUILD_WIZARD=ON \
       -DBUILD_MWINIIMPORTER=ON \
       -DBUILD_ESSIMPORTER=ON \
       -DBUILD_BSATOOL=ON \
       -DBUILD_ESMTOOL=ON \
       -DBUILD_NIFTEST=ON \
       -DOPENMW_USE_SYSTEM_RECASTNAVIGATION=ON \
       -DOPENMW_USE_SYSTEM_MYGUI=ON \
       -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DDEPLOY_QT_TRANSLATIONS=OFF \
       -DOPENMW_USE_SYSTEM_OSG=ON \
       -DOPENMW_USE_SYSTEM_BULLET=ON \
       -DOPENMW_LTO_BUILD=ON


%cmake_build


%install
%cmake_install
# DT Not sure why I need to add this here ...
#install -p -D -m644 files/org.openmw.cs.desktop %{buildroot}%{_datadir}/applications/org.openmw.cs.desktop
# DT
desktop-file-validate %{buildroot}/%{_datadir}/applications/org.openmw.cs.desktop
desktop-file-validate %{buildroot}/%{_datadir}/applications/org.openmw.launcher.desktop

# DT - manually install libopenmw-cs.so - Why?
# install -p -D -m755 redhat-linux-build/libopenmw-cs.so         %{buildroot}%{_libdir}/libopenmw-cs.so


# Test and install appdata file
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/%{name}.appdata.xml

# Remove font license file
rm -rf "%{buildroot}/%{_datadir}/licenses/%{name}/DejaVuFontLicense.txt"

# Create data directory
mkdir -p %{buildroot}/%{_datadir}/%{name}/data

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_bindir}/%{name}-launcher
%{_bindir}/%{name}-iniimporter
%{_bindir}/%{name}-essimporter
%{_bindir}/%{name}-wizard
%{_bindir}/%{name}-cs
%{_bindir}/esmtool
%{_bindir}/bsatool
%{_bindir}/niftest
%{_bindir}/%{name}-navmeshtool
%{_bindir}/%{name}-bulletobjecttool
# %%{_libdir}/Plugin_MyGUI_OpenMW_Resources.so
%{_datadir}/%{name}/
%{_datadir}/applications/org.openmw.cs.desktop
%{_datadir}/applications/org.openmw.launcher.desktop
%{_datadir}/pixmaps/%{name}-cs.png
%{_datadir}/pixmaps/%{name}.png
%{_metainfodir}/%{name}.appdata.xml
%config(noreplace) %{_sysconfdir}/openmw/

##%%files cs
##%%{_bindir}/%{name}-cs
##%%{_libdir}/libopenmw-cs.so
##%%{_datadir}/applications/org.openmw.cs.desktop
##%%{_datadir}/pixmaps/%{name}-cs.png

%changelog
%autochangelog
